@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/CustomerTicketSearch.pm - Utilities for tickets
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: CustomerTicketSearch.pm,v 1.80 2011/12/20 10:14:07 mab Exp $
+# $Id: CustomerTicketSearch.pm,v 1.80.2.2 2012/05/08 07:44:45 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -26,7 +26,7 @@ use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.80 $) [1];
+$VERSION = qw($Revision: 1.80.2.2 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -427,6 +427,10 @@ sub Run {
                     DynamicFields => 1,
                 );
 
+                for my $Key (qw(State Lock)) {
+                    $Data{$Key} = $Self->{LayoutObject}->{LanguageObject}->Get( $Data{$Key} );
+                }
+
                 $Data{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
 
                 # get whole article (if configured!)
@@ -526,8 +530,18 @@ sub Run {
                 my %UserData = $Self->{UserObject}->GetUserData( UserID => $Self->{UserID} );
                 $UserCSVSeparator = $UserData{UserCSVSeparator};
             }
+
+            my %HeaderMap = (
+                TicketNumber => 'Ticket Number',
+                CustomerName => 'customer realname',
+            );
+
+            my @CSVHeadTranslated
+                = map { $Self->{LayoutObject}->{LanguageObject}->Get( $HeaderMap{$_} || $_ ); }
+                @CSVHead;
+
             my $CSV = $Self->{CSVObject}->Array2CSV(
-                Head      => \@CSVHead,
+                Head      => \@CSVHeadTranslated,
                 Data      => \@CSVData,
                 Separator => $UserCSVSeparator,
             );
@@ -1009,11 +1023,47 @@ sub Run {
         for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
             next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
 
+            my $PossibleValuesFilter;
+
+            # check if field has PossibleValues property in its configuration
+            if ( IsHashRefWithData( $DynamicFieldConfig->{Config}->{PossibleValues} ) ) {
+
+                # get historical values from database
+                my $HistoricalValues = $Self->{BackendObject}->HistoricalValuesGet(
+                    DynamicFieldConfig => $DynamicFieldConfig,
+                );
+
+                my $Data = $DynamicFieldConfig->{Config}->{PossibleValues};
+
+                # add historic values to current values (if they don't exist anymore)
+                if ( IsHashRefWithData($HistoricalValues) ) {
+                    for my $Key ( keys %{$HistoricalValues} ) {
+                        if ( !$Data->{$Key} ) {
+                            $Data->{$Key} = $HistoricalValues->{$Key}
+                        }
+                    }
+                }
+
+                # set possible values filter from ACLs
+                my $ACL = $Self->{TicketObject}->TicketAcl(
+                    Action         => $Self->{Action},
+                    ReturnType     => 'Ticket',
+                    ReturnSubType  => 'DynamicField_' . $DynamicFieldConfig->{Name},
+                    Data           => $Data,
+                    CustomerUserID => $Self->{UserID},
+                );
+                if ($ACL) {
+                    my %Filter = $Self->{TicketObject}->TicketAclData();
+                    $PossibleValuesFilter = \%Filter;
+                }
+            }
+
             # get field html
             $DynamicFieldHTML{ $DynamicFieldConfig->{Name} } =
                 $Self->{BackendObject}->SearchFieldRender(
-                DynamicFieldConfig => $DynamicFieldConfig,
-                Profile            => \%GetParam,
+                DynamicFieldConfig   => $DynamicFieldConfig,
+                Profile              => \%GetParam,
+                PossibleValuesFilter => $PossibleValuesFilter,
                 DefaultValue =>
                     $Self->{Config}->{Defaults}->{DynamicField}->{ $DynamicFieldConfig->{Name} },
                 LayoutObject           => $Self->{LayoutObject},
